diff src/gtkutils.h @ 8289:e39ea2b4f6cd

[gaim-migrate @ 9013] - Moved GaimCheckAccountFunc into account.h, and renamed it to GaimFilterAccountFunc. - Added filter functions to the account field in the gaim_request_fields API. committer: Tailor Script <tailor@pidgin.im>
author Christian Hammond <chipx86@chipx86.com>
date Thu, 19 Feb 2004 07:25:31 +0000
parents 9af78e73f0b2
children 92cbf9713795
line wrap: on
line diff
--- a/src/gtkutils.h	Thu Feb 19 00:00:37 2004 +0000
+++ b/src/gtkutils.h	Thu Feb 19 07:25:31 2004 +0000
@@ -55,8 +55,6 @@
 } GaimBrowserPlace;
 #endif /* _WIN32 */
 
-typedef gboolean (*GaimCheckAccountFunc)(GaimAccount *account);
-
 extern guint accels_save_timer;
 
 /**
@@ -256,19 +254,19 @@
 /**
  * Creates a drop-down option menu filled with accounts.
  *
  * @param default_account    The account to select by default.
  * @param show_all           Whether or not to show all accounts, or just
  *                           active accounts.
  * @param cb                 The callback to call when an account is selected.
  * @param check_account_func A function for checking if an account should
  *                           be shown. This can be NULL.
  * @param user_data          Data to pass to the callback function.
  *
  * @return The drop-down option menu.
  */
 GtkWidget *gaim_gtk_account_option_menu_new(GaimAccount *default_account,
 		gboolean show_all, GCallback cb,
-		GaimCheckAccountFunc check_account_func, gpointer user_data);
+		GaimFilterAccountFunc filter_func, gpointer user_data);
 
 /**
  * Check if the given path is a directory or not.  If it is, then modify
@@ -256,19 +254,19 @@
  * Creates a drop-down option menu filled with accounts.
  *
- * @param default_account    The account to select by default.
- * @param show_all           Whether or not to show all accounts, or just
- *                           active accounts.
- * @param cb                 The callback to call when an account is selected.
- * @param check_account_func A function for checking if an account should
- *                           be shown. This can be NULL.
- * @param user_data          Data to pass to the callback function.
+ * @param default_account The account to select by default.
+ * @param show_all        Whether or not to show all accounts, or just
+ *                        active accounts.
+ * @param cb              The callback to call when an account is selected.
+ * @param filter_func     A function for checking if an account should
+ *                        be shown. This can be NULL.
+ * @param user_data       Data to pass to the callback function.
  *
  * @return The drop-down option menu.